This page is a companion to the WMO State of the Global climate reports. It provides access to the latest versions of selected key global indicators used in the report.

Global climate indicators (for an overview see Trewin et al. 2021) provide a broad view of climate change at the largest scale, encompassing the composition of the atmosphere, energy changes, and the responses of the land, ocean, and ice. These indicators are closely related to one another. For example, the rise in CO2 and other greenhouse gases in the atmosphere leads to an imbalance of energy and thus warming of the atmosphere and ocean. Warming of the ocean in turn leads to rising sea levels, to which is added the melting of ice on land in response to increasing atmospheric temperatures.

The global indicators draw on a wide range of data sets, which are listed at the bottom of the page. Differences between data sets for the same indicator indicate the degree of uncertainty in the indicator. Figures are updated at least annually, with some data sets being updated more frequently.

Under each of the figures, you will find links to the images in multiple file formats (png, pdf and svg), as well as a set of data as shown in the figure in a common comma-separated values (csv) format. The "Read more" link will take you to a wider range of linked indicators.

## What the IPCC says

Regarding the large-scale changes in the climate, Working Group 1 from the sixth assessment report of the Intergovernmental Panel on Climate Change concluded that:

A.1 It is unequivocal that human influence has warmed the atmosphere, ocean and land. Widespread and rapid changes in the atmosphere, ocean, cryosphere and biosphere have occurred.

A.2 The scale of recent changes across the climate system as a whole - and the present state of many aspects of the climate system - are unprecedented over many centuries to many thousands of years.

A.3 Human-induced climate change is already affecting many weather and climate extremes in every region across the globe. Evidence of observed changes in extremes such as heatwaves, heavy precipitation, droughts, and tropical cyclones, and, in particular, their attribution to human influence, has strengthened since AR5.